NAME
perldelta - what is new for perl v5.40.5
DESCRIPTION
This document describes differences between the 5.40.4 release and the 5.40.5 release.
If you are upgrading from an earlier release such as 5.40.3, first read perl5404delta, which describes differences between 5.40.3 and 5.40.4.
Security
CVE-2026-8376 - Buffer overflow in Perl_study_chunk
Perl_study_chunk in regcomp_study.c checked the size of the joined substring buffer in characters rather than bytes. On 32-bit builds, this can lead to an integer overflow of the size of the buffer leading to out-of-bounds writes.
CVE-2026-57432 - Buffer overflow in S_measure_struct
If you call pack or unpack to operate on a structure whose computed size is too large to fit in memory, an integer overflow could happen that would result in a buffer overflow. This usually happens as a result of embedding a large number as the repeat count for an item.
CVE-2026-13221 - Regex trie 16-bit field overflow
The trie optimization in the regex engine could overflow in an alternation with more than ~65k branches. This could cause both false positives and false negatives on such regular expressions.
Incompatible Changes
There are no changes intentionally incompatible with 5.40.4. If any exist, they are bugs, and we request that you submit a report. See "Reporting Bugs" below.
Modules and Pragmata
Updated Modules and Pragmata
Archive::Tar has been upgraded from version 3.02_001 to 3.12.
This fixes CVE-2026-9538, CVE-2026-42496, and CVE-2026-42497.
Compress::Raw::Bzip2 has been upgraded from version 2.212 to 2.218.
HTTP::Tiny has been upgraded from version 0.088 to 0.096.
This fixes CVE-2026-7010 and CVE-2026-7017.
IO::Compress has been upgraded from version 2.212 to 2.223.
This fixes CVE-2025-15649, CVE-2026-48961, CVE-2026-48962, and CVE-2026-48959.
Module::CoreList has been upgraded from version 5.20260329_40 to 5.20260802_40.
Socket has been upgraded from version 2.038 to 2.041.
This fixes CVE-2026-12087.
Storable has been upgraded from version 3.32 to 3.32_01.
This fixes CVE-2026-57433.
Documentation
Changes to Existing Documentation
We have attempted to update the documentation to reflect the changes listed in this document. If you find any we have missed, open an issue at https://github.com/Perl/perl5/issues.
Diagnostics
The following additions or changes have been made to diagnostic output, including warnings and fatal error messages. For the complete list of diagnostic messages, see perldiag.
New Diagnostics
New Errors
Pack template structure size is too large
(F) You called
packorunpackto operate on a structure, whose computed size is too large to fit in memory. This usually happens as a result of embedding a large number as the repeat count for an item.
Testing
Tests were added and changed to reflect the other additions and changes in this release.
Acknowledgements
Perl 5.40.5 represents approximately 4 months of development since Perl 5.40.4 and contains approximately 4,100 lines of changes across 130 files from 15 authors.
Excluding auto-generated files, documentation and release tools, there were approximately 2,000 lines of changes to 64 .pm, .t, .c and .h files.
Perl continues to flourish into its fourth decade thanks to a vibrant community of users and developers. The following people are known to have contributed the improvements that became Perl 5.40.5:
Aristotle Pagaltzis, Chris 'BinGOs' Williams, David Mitchell, E. Choroba, Eric Herman, Karen Etheridge, Karl Williamson, Leon Timmermans, Paul Evans, Paul Marquess, Philippe Bruhat (BooK), Richard Leach, Steve Hay, Thibault Duponchelle, Tony Cook.
The list above is almost certainly incomplete as it is automatically generated from version control history. In particular, it does not include the names of the (very much appreciated) contributors who reported issues to the Perl bug tracker.
Many of the changes included in this version originated in the CPAN modules included in Perl's core. We're grateful to the entire CPAN community for helping Perl to flourish.
For a more complete list of all of Perl's historical contributors, please see the AUTHORS file in the Perl source distribution.
Reporting Bugs
If you find what you think is a bug, you might check the perl bug database at https://github.com/Perl/perl5/issues. There may also be information at https://www.perl.org/, the Perl Home Page.
If you believe you have an unreported bug, please open an issue at https://github.com/Perl/perl5/issues. Be sure to trim your bug down to a tiny but sufficient test case.
If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker, then see "SECURITY VULNERABILITY CONTACT INFORMATION" in perlsec for details of how to report the issue.
Give Thanks
If you wish to thank the Perl 5 Porters for the work we had done in Perl 5, you can do so by running the perlthanks program:
perlthanks
This will send an email to the Perl 5 Porters list with your show of thanks.
SEE ALSO
The Changes file for an explanation of how to view exhaustive details on what changed.
The INSTALL file for how to build Perl.
The README file for general stuff.
The Artistic and Copying files for copyright information.